* ----------------------------------- BEGIN Site_Amp_Linear -------------------
      subroutine Site_Amp_Linear(per, v30, v30ref, imodel_lin, 
     :                            bv, va, amp_lin)
     
* Input parameters: per, v30, v30ref, imodel_lin
* Output parameters: bv (in terms of common log), va, amp_lin

* Returns the linear amplification, following the amp factor
* of BJF94, but using either the BJF slope (imodel = 1) or the 
* Choi and Stewart (2005) (imodel = 2) slope.  For BJF94, uses the cubic
* equations in Table 8 of BJF94 (for 5% damping and random component). 
* The value for per = 0.1 is used for all smaller periods and the per=2.0, 5.0 value 
* is used for periods longer than 2.0, 5.0 sec for imodel = 1, 2.  Note that this assumption is
* conservative; we expect the amplifications to reach unity for long enough
* periods (at least for Fourier spectra, what about for response spectra?)

* PGA corresponds to PER = 0.0

* Dates: 08/01/05 - Written by D. Boore, based on BJF94V30amp.FOR
*        03/17/07 - Added values for T = 7.5, 10.0 sec.
*        03/27/07 - I corrected an error (the if statement
 
      real per, v30, bv, va, amp
      real cbv(0:3), cva(0:3)
      real per_cs05(30), c_cs05(30)
      
      data per_cs05/0.010,0.020,0.030,0.040,0.050,
     :              0.060,0.075,0.090,0.100,0.120,
     :              0.150,0.170,0.200,0.240,0.300,
     :              0.360,0.400,0.460,0.500,0.600,
     :              0.750,0.850,1.000,1.500,2.000,
     :              3.000,4.000,5.000,
     :              7.500,10.00/
      data   c_cs05/-0.36,-0.34,-0.33,-0.31,-0.29,
     :              -0.25,-0.23,-0.23,-0.25,-0.26,
     :              -0.28,-0.29,-0.31,-0.38,-0.44,
     :              -0.48,-0.50,-0.55,-0.60,-0.66,
     :              -0.69,-0.69,-0.70,-0.72,-0.73,
     :              -0.74,-0.75,-0.75,
     :              -0.692, -0.650/
     
      nper_cs05 = 30
       
      cbv(0) = -0.21172
      cbv(1) =  0.06619
      cbv(2) = -1.35085
      cbv(3) =  0.79809
      nc_bv = 4
      
      cva(0) =  3.04586
      cva(1) =  1.69975
      cva(2) = -2.97445
      cva(3) =  1.37668
      nc_va = 4
 
      if (imodel_lin .eq. 1) then  ! BJF94 model
      
        if(per .eq. 0.0) then
          bv = -0.371
          va = 1396.0
        else 
          if (per .lt. 0.0) then
            t = 0.5
          else if (per .gt. 0.0 .and. per .lt. 0.1) then
            t = 0.1
          else if (per .gt. 2.0) then
            t = 2.0
          else
            t = per
          end if
          
          bv = cubic(t, cbv, nc_bv)
          va = 10.0**cubic(t, cva, nc_va) 
          
        end if

        ampv30 =    10.0**(bv*alog10(v30/va))
        ampv30ref = 10.0**(bv*alog10(v30ref/va))
        
        amp_lin = ampv30/ampv30ref
        
      else ! CS05 model
 
        if(per .eq. 0.0) then
          t = 0.01
        else 
          if (per .lt. 0.0) then
            t = 0.5
          else if (per .gt. 10.0) then ! corrected on 27 March 2007
                                       ! previous statement used 5.0 rather than 10.0
            t = 10.0
          else
            t = per
          end if          
        end if

        call lin_interp(per_cs05, c_cs05, nper_cs05, 
     :                          j, t, bv)
     
        va = v30ref
        amp_lin  =  10.0**(bv*alog10(v30/v30ref))
        
      end if
      
      return
      end

      function cubic(t, c, nc)
      
      real t, x, cubic
      integer nc, i
      real c(0:*)
      
      x = alog10(t/0.1)
      
      cubic = 0.0
      
      do i = 0, nc-1
        cubic = cubic + c(i)*x**float(i)
      end do
      
      return
      end
* ----------------------------------- END Site_Amp_Linear -------------------

         

